"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var I18nModule_1;
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const i18n_constants_1 = require("./i18n.constants");
const i18n_service_1 = require("./services/i18n.service");
const parse_1 = require("./utils/parse");
const path = require("path");
const i18n_language_middleware_1 = require("./middleware/i18n-language-middleware");
const core_1 = require("@nestjs/core");
const logger = new common_1.Logger('I18nService');
const defaultOptions = {
    filePattern: '*.json',
    resolvers: [],
};
let I18nModule = I18nModule_1 = class I18nModule {
    constructor(httpAdapterHost, i18nOptions, moduleRef) {
        this.httpAdapterHost = httpAdapterHost;
        this.i18nOptions = i18nOptions;
        this.moduleRef = moduleRef;
    }
    configure(consumer) {
        const adapterName = this.httpAdapterHost.httpAdapter &&
            this.httpAdapterHost.httpAdapter.constructor &&
            this.httpAdapterHost.httpAdapter.constructor.name;
        if (adapterName === 'FastifyAdapter') {
            this.moduleRef
                .create(i18n_language_middleware_1.I18nLanguageMiddleware)
                .then(i18nLanguageMiddleware => {
                this.httpAdapterHost.httpAdapter
                    .getInstance()
                    .addHook('preHandler', (req, res, done) => {
                    i18nLanguageMiddleware.use(req, res, done);
                });
            });
        }
        else {
            consumer.apply(i18n_language_middleware_1.I18nLanguageMiddleware).forRoutes('*');
        }
    }
    static forRoot(options) {
        options = this.sanitizeI18nOptions(options);
        const i18nOptions = {
            provide: i18n_constants_1.I18N_OPTIONS,
            useValue: options,
        };
        const translationsProvider = {
            provide: i18n_constants_1.I18N_TRANSLATIONS,
            useFactory: async () => {
                try {
                    return await parse_1.parseTranslations(options);
                }
                catch (e) {
                    return {};
                }
            },
        };
        return {
            module: I18nModule_1,
            providers: [
                { provide: common_1.Logger, useValue: logger },
                i18n_service_1.I18nService,
                i18nOptions,
                translationsProvider,
            ],
            exports: [i18n_service_1.I18nService],
        };
    }
    static forRootAsync(options) {
        const asyncOptionsProvider = this.createAsyncOptionsProvider(options);
        const asyncTranslationProvider = this.createAsyncTranslationProvider();
        return {
            module: I18nModule_1,
            imports: options.imports || [],
            providers: [
                { provide: common_1.Logger, useValue: logger },
                asyncOptionsProvider,
                asyncTranslationProvider,
                i18n_service_1.I18nService,
            ],
            exports: [i18n_service_1.I18nService],
        };
    }
    static createAsyncOptionsProvider(options) {
        if (options.useFactory) {
            return {
                provide: i18n_constants_1.I18N_OPTIONS,
                useFactory: options.useFactory,
                inject: options.inject || [],
            };
        }
        return {
            provide: i18n_constants_1.I18N_OPTIONS,
            useFactory: async (optionsFactory) => await optionsFactory.createI18nOptions(),
            inject: [options.useClass || options.useExisting],
        };
    }
    static createAsyncTranslationProvider() {
        return {
            provide: i18n_constants_1.I18N_TRANSLATIONS,
            useFactory: async (options) => {
                options = this.sanitizeI18nOptions(options);
                try {
                    return await parse_1.parseTranslations(options);
                }
                catch (e) {
                    return {};
                }
            },
            inject: [i18n_constants_1.I18N_OPTIONS],
        };
    }
    static sanitizeI18nOptions(options) {
        options = Object.assign({}, defaultOptions, options);
        options.path = path.normalize(options.path + path.sep);
        if (!options.filePattern.startsWith('*.')) {
            options.filePattern = '*.' + options.filePattern;
        }
        return options;
    }
};
I18nModule = I18nModule_1 = __decorate([
    common_1.Global(),
    common_1.Module({}),
    __param(1, common_1.Inject(i18n_constants_1.I18N_OPTIONS)),
    __metadata("design:paramtypes", [core_1.HttpAdapterHost, Object, core_1.ModuleRef])
], I18nModule);
exports.I18nModule = I18nModule;
//# sourceMappingURL=i18n.module.js.map